@@ -75,3 +75,10 @@ class GenomicPlatform(AnyEntity):
 
     def dc_title(self):
         return '%s %s' % (self._cw._('GenomicPlatform'), self.name)
+
+
+class Chromosome(AnyEntity):
+    __regid__ = 'Chromosome'
+
+    def dc_title(self):
+        return '%s %s' % (self._cw._('Chromosome'), self.name)
