@@ -16,8 +16,9 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-drop_relation_definition('GenomicMeasure', 'results_file', 'File')
-remove_cube('file')
-
-drop_attribute('GenomicMeasure', 'identifier')
-rename_attribute('GenomicPlatform', 'identifier', 'name')
+add_attribute('Mutation', 'classification_variant')
+add_attribute('Mutation', 'dbnsp')
+add_attribute('Mutation', 'amplicon')
+add_attribute('GenomicMeasure', 'conclusion')
+add_attribute('GenomicMeasure', 'healthy_tissue')
+add_relation_definition('GenomicMeasure', 'mutated_genes', 'Gene')
