@@ -32,17 +32,3 @@ class SnpCSVView(CSVRsetView):
             rows.append(row)
         writer = self.csvwriter()
         writer.writerows(rows)
-
-
-class GenomicMeasureCSVView(CSVRsetView):
-    """CSV view for GenomicMeasure"""
-    __select__ = CSVRsetView.__select__ & is_instance('GenomicMeasure')
-
-    def call(self):
-        req = self._cw
-        rows = [('"subject_id"', '"type"', '"format"', '"filepath"')]
-        for entity in self.cw_rset.entities():
-            rows.append([entity.subject_id, entity.type,
-                         entity.format, entity.filepath])
-        writer = self.csvwriter()
-        writer.writerows(rows)
